package tools;

/**
 * A stopwatch for performance measurement.
 */
public final class Stopwatch
{
    // Private fields

    /** Millis of the start time. */
    private long startTime = -1;

    /** Millis of the stop time. */
    private long stopTime = -1;

    /** Whether this stopwatch is running. */
    private boolean running = false;

    // Public methods

    /** Starts this stopwatch. */
    public Stopwatch start()
    {
	startTime = System.currentTimeMillis();
	running = true;
	return this;
    }

    /** Stops this stopwatch. */
    public Stopwatch stop()
    {
	stopTime = System.currentTimeMillis();
	running = false;
	return this;
    }

    /**
     * Returns elapsed time in milliseconds; 0 if this watch has not been
     * started.
     */
    public long getElapsedTime()
    {
	if (startTime < 0) {
	    return 0;
	}

	return (running ? System.currentTimeMillis() : stopTime) - startTime;
    }

    /** Resets this stopwatch. */
    public Stopwatch reset()
    {
	startTime = -1;
	stopTime = -1;
	running = false;
	return this;
    }
}
